==> zio-aws-docdb_2.13-5.17.146.2-sources.jar: zio/aws/docdb/model/AddSourceIdentifierToSubscriptionResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AddSourceIdentifierToSubscriptionResponse(
    eventSubscription: Option[zio.aws.docdb.model.EventSubscription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse = {
    import AddSourceIdentifierToSubscriptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
      .builder()
      .optionallyWith(eventSubscription.map(value => value.buildAwsValue()))(
        _.eventSubscription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly =
    zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse
      .wrap(buildAwsValue())
}
object AddSourceIdentifierToSubscriptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse =
      zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse(
        eventSubscription.map(value => value.asEditable)
      )
    def eventSubscription
        : Option[zio.aws.docdb.model.EventSubscription.ReadOnly]
    def getEventSubscription
        : ZIO[Any, AwsError, zio.aws.docdb.model.EventSubscription.ReadOnly] =
      AwsError.unwrapOptionField("eventSubscription", eventSubscription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ) extends zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly {
    override val eventSubscription
        : Option[zio.aws.docdb.model.EventSubscription.ReadOnly] = scala
      .Option(impl.eventSubscription())
      .map(value => zio.aws.docdb.model.EventSubscription.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ): zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-docdb_2.13-5.17.188.1-sources.jar: zio/aws/docdb/model/AddSourceIdentifierToSubscriptionResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AddSourceIdentifierToSubscriptionResponse(
    eventSubscription: Optional[zio.aws.docdb.model.EventSubscription] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse = {
    import AddSourceIdentifierToSubscriptionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
      .builder()
      .optionallyWith(eventSubscription.map(value => value.buildAwsValue()))(
        _.eventSubscription
      )
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly =
    zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse
      .wrap(buildAwsValue())
}
object AddSourceIdentifierToSubscriptionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse =
      zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse(
        eventSubscription.map(value => value.asEditable)
      )
    def eventSubscription
        : Optional[zio.aws.docdb.model.EventSubscription.ReadOnly]
    def getEventSubscription
        : ZIO[Any, AwsError, zio.aws.docdb.model.EventSubscription.ReadOnly] =
      AwsError.unwrapOptionField("eventSubscription", eventSubscription)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ) extends zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly {
    override val eventSubscription
        : Optional[zio.aws.docdb.model.EventSubscription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.eventSubscription())
        .map(value => zio.aws.docdb.model.EventSubscription.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.AddSourceIdentifierToSubscriptionResponse
  ): zio.aws.docdb.model.AddSourceIdentifierToSubscriptionResponse.ReadOnly =
    new Wrapper(impl)
}
